ImageProperties class

Constructors

ImageProperties({MediaFormat format = const MediaFormat.unknownImage(), int width = -1, int height = -1, String colorSpace = "sRGB"})
ImageProperties.fromMagickOutput(String s)

Properties

aspectRatio → double
no setter
colorSpace → String
final
format → MediaFormat
final
hashCode → int
The hash code for this object.
no setterinherited
height → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resize(int newWidth, int newHeight) → ImageProperties
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited