magick/src/image_magick library

Classes

AffineMatrix
Represents an affine matrix.
ChannelFeatures
Represents features of a channel in an image.
ChannelStatistics
Represents the statistics of a channel.
DrawGetExceptionResult
Represents a result to a call to DrawingWand.drawGetException.
DrawGetFontResolutionResult
Represents a result to a call to DrawingWand.drawGetFontResolution.
DrawingWand
A DrawingWand is a wand that contains vector drawing methods.
ImageMagickFFIPlugin
KernelInfo
Represents an image kernel matrix.
MagickGetExceptionResult
Represents an exception that occurred while using the ImageMagick API.
MagickGetImageBluePrimaryResult
MagickGetImageGreenPrimaryResult
Represents the result of a call to magickGetImageGreenPrimary.
MagickGetImageKurtosisResult
Represents the result of a call to magickGetImageKurtosis.
MagickGetImageMeanResult
Represents the result of a call to magickGetImageMean.
MagickGetImagePageResult
Represents the result of a call to magickGetImagePage.
MagickGetImageRangeResult
Represents the result of a call to magickGetImageRange.
MagickGetImageRedPrimaryResult
Represents the result of a call to magickGetImageRedPrimary.
MagickGetImageResolutionResult
Represents the result of a call to magickGetImageResolution.
MagickGetImageWhitePointResult
Represents the result of a call to magickGetImageWhitePoint.
MagickGetPageResult
Represents a result to a call to magickGetPage().
MagickGetQuantumDepthResult
Represents a result to a call to magickGetQuantumDepth().
MagickGetQuantumRangeResult
Represents a result to a call to magickGetQuantumRange().
MagickGetResolutionResult
Represents a result to a call to magickGetResolution().
MagickGetSizeResult
Represents a result to a call to magickGetSize().
MagickGetVersionResult
Represents a result to a call to magickGetVersion().
MagickWand
The MagickWand can do operations on images like reading, resizing, writing, cropping an image, etc...
PixelGetExceptionResult
Represents a result to a call to pixelGetException.
PixelGetHSLResult
Represents a result to a call to pixelGetHSL.
PixelGetIteratorExceptionResult
Represents a result to a call to PixelIterator.pixelGetIteratorException.
PixelInfo
Represents a pixel info.
PixelIterator
A pixel iterator that can be used to iterate over the pixels of an image.
PixelWand
PixelWand is used to manage and control pixels in an image.
PointInfo
Represents a point in a 2D space.
SegmentInfo
A class that represents a segment info.
TypeMetric
A class that represents a type metric.

Enums

AlignType
Represents an align type.
AlphaChannelOption
Represents an alpha channel type.
AutoThresholdMethod
Represents an auto-threshold method.
ChannelType
Represents a channel type.
ClassType
Represents a class type.
ClipPathUnits
Represents a clip path unit.
ColorspaceType
Represents a colorspace type.
ComplexOperator
Represents a complex operator.
CompositeOperator
Represents a composite operator.
CompressionType
Represents an image compression type.
DecorationType
Represents a text decoration
DirectionType
Represents a text direction.
DisposeType
Represents an image dispose type
DistortMethod
Represent an image distortion method.
DitherMethod
Represents a dither method.
EndianType
Represents an endiannness type.
ExceptionType
Represents the type of an exception that occurred when using the ImageMagick API.
FillRule
Represents a fill rule.
FilterType
Represents a filter type.
GravityType
Represents a gravity type.
ImageType
Represents an image type.
InterlaceType
Represents an interlace type.
KernelInfoType
Represents a kernel type.
LayerMethod
Represents a layer method.
LineCap
Represents a line cap.
LineJoin
Represents a line join.
MagickEvaluateOperator
Represents an evaluation operator.
MagickFunctionType
Represents a magick function
MetricType
Represents a metric type.
MontageMode
Represents a montage mode.
MorphologyMethod
Represents a morphology method.
NoiseType
Represents a noise type.
OrientationType
Represents an orientation type.
PaintMethod
Represents a paint method.
PixelInterpolateMethod
Represents a pixel interpolation method.
PixelMask
Represents a pixel mask.
PixelTrait
Represents a pixel trait.
PreviewType
Represents a preview type.
RenderingIntent
Represents a rendering intent.
ResolutionType
Represents a resolution type.
ResourceType
Represents a resource type.
SparseColorMethod
Represents a sparse color method.
StatisticType
Represents a statistic type.
StretchType
Represents a stretch type.
StyleType
Represents a style type.
VirtualPixelMethod
Represents a virtual pixel method.

Functions

disposeImageMagick() → void
Disposes the resources used with the plugin.
initializeImageMagick() → void
Initializes the necessary resources used with the plugin. This must be called before any use of the plugin.
isMagickWandInstantiated() → bool
Returns true if the ImageMagick environment is currently instantiated-- that is, magickWandGenesis() has been called but magickWandTerminus() has not.
magickGetCopyright() → String
Returns the ImageMagick API copyright as a string.
magickGetHomeURL() → String
Returns the ImageMagick home URL.
magickGetPackageName() → String
Returns the ImageMagick package name.
magickGetQuantumDepth() → MagickGetQuantumDepthResult
Returns the ImageMagick quantum depth.
magickGetQuantumRange() → MagickGetQuantumRangeResult
Returns the ImageMagick quantum range.
magickGetReleaseDate() → String
Returns the ImageMagick release date.
magickGetResource(ResourceType type) → int
Returns the specified resource in megabytes.
magickGetResourceLimit(ResourceType type) → int
Returns the specified resource limit in megabytes.
magickGetVersion() → MagickGetVersionResult
Returns the ImageMagick version.
magickQueryConfigureOption(String option) → String?
Returns the value associated with the specified configure option, or null in case of no match.
magickQueryConfigureOptions(String pattern) → List<String>?
Returns any configure options that match the specified pattern (e.g. "*" for all). Options include NAME, VERSION, LIB_VERSION, etc.
magickQueryFonts(String pattern) → List<String>?
Returns any font that match the specified pattern (e.g. "*" for all).
magickQueryFormats(String pattern) → List<String>?
Returns any image formats that match the specified pattern (e.g. "*" for all).
magickSetResourceLimit(ResourceType type, int limit) → bool
Sets the limit for a particular resource in megabytes.
magickSetSeed(int seed) → void
Sets the pseudo-random number generator seed. Use it to generate a predictable sequence of random numbers.

Typedefs

MagickProgressMonitor = void Function(String info, int offset, int size, dynamic clientData)
Signature for a callback to be called when an operation's progress changes.