PixelGetIteratorExceptionResult class

Represents a result to a call to PixelIterator.pixelGetIteratorException.

Constructors

PixelGetIteratorExceptionResult(ExceptionType severity, String description)
const

Properties

description → String
The description of the exception.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
severity → ExceptionType
The severity of the exception.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited