PixelIterator class

A pixel iterator that can be used to iterate over the pixels of an image.

Create a new pixel iterator using newPixelIterator or newPixelRegionIterator.

When done with a PixelIterator, destroy it with destroyPixelIterator.

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

clearPixelIterator() → void
Clear resources associated with a PixelIterator.
clonePixelIterator() → PixelIterator
Make an exact copy of the specified iterator.
destroyPixelIterator() → void
DestroyPixelIterator() deallocates resources associated with a PixelIterator. Never use a pixel iterator after it has been destroyed.
isPixelIterator() → bool
Returns true if the iterator is verified as a pixel iterator.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pixelClearIteratorException() → bool
Clear any exceptions associated with the iterator.
pixelGetCurrentIteratorRow() → Future<List<PixelWand>>
Returns the current row as an array of pixel wands from the pixel iterator.
pixelGetIteratorException() → PixelGetIteratorExceptionResult
Returns the severity, reason, and description of any error that occurs when using other methods in this API.
pixelGetIteratorExceptionType() → ExceptionType
Returns the exception type associated with the iterator.
pixelGetIteratorRow() → int
Returns the current pixel iterator row.
pixelGetNextIteratorRow() → Future<List<PixelWand>>
Returns the next row as an array of pixel wands from the pixel iterator.
pixelGetPreviousIteratorRow() → Future<List<PixelWand>>
Returns the previous row as an array of pixel wands from the pixel iterator.
pixelResetIterator() → void
Resets the pixel iterator. Use it in conjunction with pixelGetNextIteratorRow to iterate over all the pixels in a pixel container.
pixelSetFirstIteratorRow() → void
Sets the pixel iterator to the first pixel row.
pixelSetIteratorRow(int row) → bool
Set the pixel iterator row.
pixelSetLastIteratorRow() → void
Sets the pixel iterator to the last pixel row.
pixelSyncIterator() → Future<bool>
Syncs the pixel iterator.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

newPixelIterator(MagickWand wand) → PixelIterator?
Returns a new pixel iterator.
newPixelRegionIterator({required MagickWand wand, required int x, required int y, required int width, required int height}) → PixelIterator?
Returns a new pixel iterator for a region of the image. Don't forget to destroy the returned iterator using destroyPixelIterator when you are done with it.