IPipelineJob class abstract

Implementers

Constructors

IPipelineJob()

Properties

count → int
no setter
hashCode → int
The hash code for this object.
no setterinherited
priority → int
Higher priority jobs run first before lower priority jobs.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

blind() → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
then(IPipelineJob next) → IPipelineJob
toString() → String
A string representation of this object.
inherited
transform(MediaPipeline pipeline) → Future<void>

Operators

operator ==(Object other) → bool
The equality operator.
inherited