ImageOptimizerWebPJob class

Inheritance

Constructors

ImageOptimizerWebPJob({String wandKey = "wand", double initialStepMultiplier = 10, int initialQuality = 75, double stepMultiplierCutoff = 1.05, int maxDimension = 1024, int maxBytes = 1024 * 1024, int maxAttempts = 15, int plentifulSpaceQualityThreshold = 95, required File output, PixelInterpolateMethod interpolateMethod = PixelInterpolateMethod.BilinearInterpolatePixel})

Properties

count → int
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
initialQuality → int
final
initialStepMultiplier → double
final
interpolateMethod → PixelInterpolateMethod
final
maxAttempts → int
final
maxBytes → int
final
maxDimension → int
final
output → File
final
plentifulSpaceQualityThreshold → int
final
priority → int
Higher priority jobs run first before lower priority jobs.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stepMultiplierCutoff → double
final
wandKey → String
finalinherited

Methods

blind() → Future<void>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
then(IPipelineJob next) → IPipelineJob
inherited
toString() → String
A string representation of this object.
inherited
transform(MediaPipeline pipeline) → Future<void>
inherited
wandTransform(MediaPipeline pipeline, MagickWand wand) → Future<void>
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited