ImageWriteJob class

Inheritance

Constructors

ImageWriteJob({String wandKey = "wand", required File output, int priority = 0, CompressionType compressionType = CompressionType.WebPCompression, String format = "webp", int quality = 100})
ImageWriteJob.jpg({String wandKey = "wand", required File output, int priority = 0, int quality = 100})
ImageWriteJob.png({String wandKey = "wand", required File output, int priority = 0})
ImageWriteJob.webp({String wandKey = "wand", required File output, int priority = 0, int quality = 100})

Properties

compressionType → CompressionType
final
count → int
no setterinherited
format → String
final
hashCode → int
The hash code for this object.
no setterinherited
output → File
final
priority → int
Higher priority jobs run first before lower priority jobs.
final
quality → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
wandKey → String
finalinherited

Methods

blind() → Future<void>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
then(IPipelineJob next) → IPipelineJob
inherited
toString() → String
A string representation of this object.
inherited
transform(MediaPipeline pipeline) → Future<void>
inherited
wandTransform(MediaPipeline pipeline, MagickWand wand) → Future<void>
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited