MagickImageLoaderJob class

Inheritance

Constructors

MagickImageLoaderJob(File image, {String wandKey = "wand", int? maxDim, String? formatHint})

Properties

count → int
no setterinherited
formatHint → String?
final
hashCode → int
The hash code for this object.
no setterinherited
image → File
final
maxDim → int?
final
priority → int
Higher priority jobs run first before lower priority jobs.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
wandKey → String
final

Methods

blind() → Future<void>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
then(IPipelineJob next) → IPipelineJob
inherited
toString() → String
A string representation of this object.
inherited
transform(MediaPipeline pipeline) → Future<void>
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited