MagickPipelineJob class abstract

A job that runs a single transformation using a shared MagickWand.

Inheritance
Implementers

Constructors

MagickPipelineJob({String wandKey = "wand"})

Properties

count → int
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
priority → int
Higher priority jobs run first before lower priority jobs.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
wandKey → String
final

Methods

blind() → Future<void>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
then(IPipelineJob next) → IPipelineJob
inherited
toString() → String
A string representation of this object.
inherited
transform(MediaPipeline pipeline) → Future<void>
override
wandTransform(MediaPipeline pipeline, MagickWand wand) → Future<void>

Operators

operator ==(Object other) → bool
The equality operator.
inherited